@@ -1,9 +1,9 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
 # SoundConverter - GNOME application for converting between audio formats.
 # Copyright 2004 Lars Wirzenius
-# Copyright 2005-2012 Gautier Portet
+# Copyright 2005-2017 Gautier Portet
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,18 +27,20 @@ def _notification_dummy(message):
 notification = _notification_dummy
 
 try:
-    import pynotify
+    import gi
+    gi.require_version('Notify', '0.7')
+    from gi.repository import Notify
 
 
     def _notification(message):
         try:
-            n = pynotify.Notification('SoundConverter', message)
+            n = Notify.Notification('SoundConverter', message)
             n.show()
         except:
             pass 
 
-    if pynotify.init('Basics'):
+    if Notify.init('Basics'):
         notification = _notification
 
-except ImportError:
+except (ImportError, ValueError):
     pass
