@@ -1,9 +1,9 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 #
 # SoundConverter - GNOME application for converting between audio formats.
 # Copyright 2004 Lars Wirzenius
-# Copyright 2005-2012 Gautier Portet
+# Copyright 2005-2017 Gautier Portet
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,9 +20,9 @@
 # USA
 
 import time
-from task import BackgroundTask
-from settings import settings
-from utils import log
+from soundconverter.task import BackgroundTask
+from soundconverter.settings import settings
+from soundconverter.utils import log
 
 
 class TaskQueue(BackgroundTask):
@@ -50,6 +50,8 @@ class TaskQueue(BackgroundTask):
         self.start_time = None
         self.count = 0
         self.paused = False
+        self.jobs = settings['forced-jobs'] or settings['jobs']
+        self.jobs = self.jobs or settings['cpu-count']
 
     def add_task(self, task):
         """Add a task to the queue."""
@@ -65,7 +67,7 @@ class TaskQueue(BackgroundTask):
                 self.done()
             return
 
-        to_start = settings['jobs'] - len(self.running_tasks)
+        to_start = self.jobs - len(self.running_tasks)
         for i in range(to_start):
             try:
                 task = self.waiting_tasks.pop(0)
@@ -82,9 +84,9 @@ class TaskQueue(BackgroundTask):
 
     def started(self):
         """ BackgroundTask setup callback """
+        jobs = settings['jobs'] or settings['cpu-count']
         log('Queue start: %d tasks, %d thread(s).' % (
-            len(self.waiting_tasks) + len(self.running_tasks),
-            settings['jobs']))
+            len(self.waiting_tasks) + len(self.running_tasks), self.jobs))
         self.count = 0
         self.paused = False
         self.finished_tasks = 0
